<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/operationRecord/save' : '/api/operationRecord/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const UserQueryList = ref(null); 
UserQuery();
function UserQuery() { 
    postForm('/api/user/query', {}).then(resp => { 
        let result = resp.data;
        UserQueryList.value = result.data;
    })
}


defineExpose({
    open,
    formData,
    initFormData,
    isSave,
})

</script>

<script>
export default {
    name: '操作日志-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" name="formTable" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.namespace', '名称空间') " 
                      name="namespace" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.namespace" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.url', '接口地址') " 
                      name="url" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.url" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.appkey', '平台密钥') " 
                      name="appkey" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.appkey" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.timestamp', '时间戳') " 
                      name="timestamp" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.timestamp" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.client_ip', '客户端IP') " 
                      name="clientIp" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.clientIp" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.request', '请求内容') " 
                      name="request" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.request" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.response', '响应内容') " 
                      name="response" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.response" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.spend_time', '消耗时间') " 
                      name="spendTime" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.spendTime" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.err', '异常内容') " 
                      name="err" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.err" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.result', '结果') " 
                      name="result" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.result" 
                        :options="[
                                { label: '成功', value: 1 },
                                { label: '失败', value: 0 },
                            ]"
                        >
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.user_id', '用户') " 
                      name="userId" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.userId" 
                        placeholder="Select users" 
                        style="width: 100%" 
                        show-search 
                        :options="UserQueryList" 
                        optionFilterProp="label" 
                        optionLabelProp="label" 
                     > 
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.create_time', '添加时间') " 
                      name="createTime" 
                      style="width: 250px;" 
                            >
                    <a-date-picker 
                        v-model:value="formData.createTime" 
                        show-time 
                        format="YYYY-MM-DD HH:mm:ss" 
                        value-format="YYYY-MM-DD HH:mm:ss" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.sys_operation_record.memo', '备注') " 
                      name="memo" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.memo" 
                     /> 
                        </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
